<?php

namespace CyclivePrivate\MainBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use JMS\SecurityExtraBundle\Security\Authorization\Expression\Expression;

use CyclivePublic\UserBundle\Entity\User;
use CyclivePublic\MainBundle\Entity\News;
use CyclivePublic\ObjectBundle\Entity\ObjectList;
use CyclivePublic\ObjectBundle\Entity\UserObject;

class MainController extends Controller
{
    public function homeAction()
    {
    	if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

		$em = $this->getDoctrine()->getManager();
		$user = $this->get('security.context')->getToken()->getUser();
		if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

		return $this->render('CyclivePrivateMainBundle::home.html.twig', array(
		));
    }

    public function objectFormAction()
    {
        if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

        $em = $this->getDoctrine()->getManager();
        $user = $this->get('security.context')->getToken()->getUser();
        if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

        $request = $this->getRequest();

		if ($request->getMethod() == 'POST') {
			$object = new ObjectList();
			$object->setName($_POST['name']);
			$object->setStringId($_POST['stringId']);
			$object->setDescription($_POST['description']);
			$date = new \Datetime();
			$object->setDateAdded($date);
			$object->setRepairLink1($_POST['rLink1']);
			$object->setRepairLink2($_POST['rLink2']);
			$object->setRepairLink3($_POST['rLink3']);

			$em->persist($object);
			$em->flush();

			return $this->objectListAction();
		}

		return $this->render('CyclivePrivateMainBundle::objectForm.html.twig', array(
		));
    }

    public function objectListAction()
    {
    	if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

        $em = $this->getDoctrine()->getManager();
		$user = $this->get('security.context')->getToken()->getUser();
		if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

        $repObjectList = $em->getRepository('CyclivePublicObjectBundle:ObjectList');
		$objects = $repObjectList->findAll();

		return $this->render('CyclivePrivateMainBundle::objectList.html.twig', array(
			'objects' => $objects,
		));
    }

    public function objectDeleteAction($objId)
    {
    	if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

        $em = $this->getDoctrine()->getManager();
		$user = $this->get('security.context')->getToken()->getUser();
		if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

        $repObjectList = $em->getRepository('CyclivePublicObjectBundle:ObjectList');
		$object = $repObjectList->find($objId);

		if($object !== null){
			$em->remove($object);
			$em->flush();
		}

		return $this->objectListAction();
    }

    public function newsFormAction()
    {
    	if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

		$em = $this->getDoctrine()->getManager();
		$user = $this->get('security.context')->getToken()->getUser();
		if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

        $em = $this->getDoctrine()->getManager();
        $user = $this->get('security.context')->getToken()->getUser();
        $request = $this->getRequest();

		if ($request->getMethod() == 'POST') {
			$news = new News();
			$news->setTitle($_POST['title']);
			$news->setContent($_POST['content']);
			$news->setAuthor($user);
			$date = new \Datetime();
			$news->setDateAdded($date);
			$news->setDateEdited($date);

			$em->persist($news);
			$em->flush();

			return $this->newsListAction();
		}

		return $this->render('CyclivePrivateMainBundle::newsForm.html.twig', array(
		));
    }

    public function newsListAction()
    {
        if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

        $em = $this->getDoctrine()->getManager();
		$user = $this->get('security.context')->getToken()->getUser();
		if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

        $repNews = $em->getRepository('CyclivePublicMainBundle:News');
		$news = $repNews->findAll();

		return $this->render('CyclivePrivateMainBundle::newsList.html.twig', array(
			'news' => $news,
		));
    }

    public function newsDeleteAction($newsId)
    {
    	if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

        $em = $this->getDoctrine()->getManager();
		$user = $this->get('security.context')->getToken()->getUser();
		if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

        $repNewsList = $em->getRepository('CyclivePublicMainBundle:News');
		$news = $repNewsList->find($newsId);

		if($news !== null){
			$em->remove($news);
			$em->flush();
		}

		return $this->newsListAction();
    }

    public function membersListAction()
    {
        if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

        $em = $this->getDoctrine()->getManager();
		$user = $this->get('security.context')->getToken()->getUser();
		if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

        $repUser = $em->getRepository('CyclivePublicUserBundle:User');
		$users = $repUser->findAll();

		return $this->render('CyclivePrivateMainBundle::membersList.html.twig', array(
			'users' => $users,
		));
    }

    public function membersDeleteAction($memId)
    {
    	if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

        $em = $this->getDoctrine()->getManager();
		$user = $this->get('security.context')->getToken()->getUser();
		if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

        $repUser = $em->getRepository('CyclivePublicUserBundle:User');
		$user = $repUser->find($memId);

		if($user !== null){
			$em->remove($user);
			$em->flush();
		}

		return $this->membersListAction();
    }

    public function activitiesListAction()
    {
        if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

        $em = $this->getDoctrine()->getManager();
		$user = $this->get('security.context')->getToken()->getUser();
		if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

        $repActivity = $em->getRepository('CyclivePrivateMainBundle:Activity');
		$activities = $repActivity->findAll();

		return $this->render('CyclivePrivateMainBundle::activitiesList.html.twig', array(
			'activities' => $activities,
		));
    }

    public function requestListAction()
    {
        if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

        $em = $this->getDoctrine()->getManager();
		$user = $this->get('security.context')->getToken()->getUser();
		if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

        $repRequest = $em->getRepository('CyclivePublicMainBundle:Request');
		$request = $repRequest->findAll();

		return $this->render('CyclivePrivateMainBundle::requestList.html.twig', array(
			'request' => $request,
		));
    }

    public function requestDeleteAction($reqId)
    {
    	if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

        $em = $this->getDoctrine()->getManager();
		$user = $this->get('security.context')->getToken()->getUser();
		if (!($user->getIsAdmin())) {
        	return $this->redirect( $this->generateUrl('cyclive_public_home') );
        }

        $repReq = $em->getRepository('CyclivePublicMainBundle:Request');
		$req = $repReq->find($reqId);

		if($req !== null){
			$em->remove($req);
			$em->flush();
		}

		return $this->requestListAction();
    }
}
