<?php

namespace CyclivePublic\ObjectBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Httpfoundation\Response;
use JMS\SecurityExtraBundle\Security\Authorization\Expression\Expression;

//use CyclivePublic\ObjectBundle\Entity\Announce;
use CyclivePublic\ObjectBundle\Entity\UserObject;
use CyclivePublic\ObjectBundle\Entity\ObjectList;
use CyclivePrivate\MainBundle\Entity\Activity;
use CyclivePublic\UserBundle\Entity\User;

class ObjectController extends Controller
{
	public function objectsListAction()
	{
		$em = $this->getDoctrine()->getManager();

		$repObjectList = $em->getRepository('CyclivePublicObjectBundle:ObjectList');
		$objects = $repObjectList->findAll();

		return $this->render('CyclivePublicObjectBundle::objectsList.html.twig', array(
    	'activeNavLink'  => '1',
    	'objects' => $objects,
		));
	}

	public function myObjectsListAction()
	{
		$em = $this->getDoctrine()->getManager();
		if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

		$user = $this->get('security.context')->getToken()->getUser();
		
		$repUserObject = $em->getRepository('CyclivePublicObjectBundle:UserObject');
		$objects = $repUserObject->findBy(array('owner' => $user));

		return $this->render('CyclivePublicObjectBundle::myObjectsList.html.twig', array(
    	'activeNavLink'  => '1',
    	'objects' => $objects,
		));
	}

	public function viewObjectAction($strId)
	{
		$em = $this->getDoctrine()->getManager();

		$repObjectList = $em->getRepository('CyclivePublicObjectBundle:ObjectList');
		$object = $repObjectList->findOneBy(array('stringId' => $strId));

		if ($object === null) {
			$session = $this->getRequest()->getSession();
            $flash = $session->getFlashBag();
            $flash->add('alertdanger', 'Cet objet n\'existe pas !');
            return $this->objectsListAction();
		}

		if(($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			$user = $this->get('security.context')->getToken()->getUser();

			$repUserObject = $em->getRepository('CyclivePublicObjectBundle:UserObject');
			$userObject = $repUserObject->findOneBy(array('object' => $object));

			if($userObject === null){
				$isInMyList = false;
			}else{
				$isInMyList = true;
			}
		} else {
			$isInMyList = false;
		}
		
		

		return $this->render('CyclivePublicObjectBundle::viewObject.html.twig', array(
    	'activeNavLink'  => '1',
    	'object' => $object,
    	'isInMyList' => $isInMyList
		));
	}

	public function addObjectToMeAction($strId)
	{
		$em = $this->getDoctrine()->getManager();
		if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			
			// Sauvegarde du lien pour redirection
			$session = $this->getRequest()->getSession();
			$session->set('actionEnAttente', "ajout");
            $session->set('objet', $strId);

			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

		$user = $this->get('security.context')->getToken()->getUser();
		
		$repObjectList = $em->getRepository('CyclivePublicObjectBundle:ObjectList');
		$object = $repObjectList->findOneBy(array('stringId' => $strId));
		$repUserObject = $em->getRepository('CyclivePublicObjectBundle:UserObject');
		$userObject = $repUserObject->findOneBy(array('object' => $object));

		$repActivity = $em->getRepository('CyclivePrivateMainBundle:Activity');

		if($userObject === null){
			$act = new Activity();
			$act->setUser($user);
			$act->setMessage("A ajouté un objet à sa liste");
			$act->setDate(new \Datetime());
			$em->persist($act);
			$userObject = new UserObject();
			$userObject->setOwner($user);
			$userObject->setObject($object);
			$em->persist($userObject);
   			$em->flush();

   			$session = $this->getRequest()->getSession();
            $flash = $session->getFlashBag();
            $flash->add('alertsuccess', 'Objet ajouté à votre liste !');
		}
		
		return $this->viewObjectAction($object->getStringId());
	}

	public function removeObjectFromMeAction($strId)
	{
		$em = $this->getDoctrine()->getManager();
		if(!($this->get('security.context')->isGranted(array(new Expression('isAuthenticated()'))))){
			return $this->redirect( $this->generateUrl('fos_user_security_login') );
		}

		$user = $this->get('security.context')->getToken()->getUser();
		$repObjectList = $em->getRepository('CyclivePublicObjectBundle:ObjectList');
		$repUserObject = $em->getRepository('CyclivePublicObjectBundle:UserObject');

		$object = $repObjectList->findOneBy(array('stringId' => $strId));
		$userObject = $repUserObject->findOneBy(array('object' => $object,'owner' => $user));

		if($userObject === null){

		}else{
			$em->remove($userObject);
			$em->flush();

			$session = $this->getRequest()->getSession();
            $flash = $session->getFlashBag();
            $flash->add('alertsuccess', 'Objet retiré de votre liste !');
		}
		
		return $this->redirect( $this->generateUrl('cyclive_public_myObjectsList') );
	}
}